@@ -1,4 +1,6 @@
 import os
+import sys
+import subprocess
 
 class GitCPP:
     def __init__(self, git_path):
@@ -9,7 +11,8 @@ class GitCPP:
 
     def cmd(self, cmd):
         if self.is_repository():
-            os.system("cd %s; git %s"%(self.git_path, cmd))
+            os.chdir(self.git_path)
+            subprocess.call(("git %s"%cmd).encode(sys.stdout.encoding), shell=True)
 
     def commit(self, commit_message):
         self.cmd("add -A")
